microsoft-dia-0.12.0 has been yanked.
Visit the last successful build:
microsoft-dia-0.8.0
Rust for Debug Interface Access (DIA) SDK
The Microsoft Debug Interface Access Software Development Kit (DIA SDK) provides access to debug information stored in program database (.pdb) files generated by Microsoft postcompiler tools.
Start by adding windows-core and microsoft-dia dependencies to Cargo.toml:
[]
= "0.59"
[]
= "0.12"
Make use of any DIA SDK APIs as needed.
use ;
use *;